@@ -356,9 +356,7 @@ populate_ui (CEPageBond *self)
 	} else {
 		mtu_def = mtu_val = 0;
 	}
-	g_signal_connect (priv->mtu, "output",
-	                  G_CALLBACK (ce_spin_output_with_automatic),
-	                  GINT_TO_POINTER (mtu_def));
+	ce_spin_automatic_val (priv->mtu, mtu_def);
 	gtk_spin_button_set_value (priv->mtu, (gdouble) mtu_val);
 }
 
@@ -389,6 +387,7 @@ add_slave (CEPageMaster *master, NewConnectionResultFunc result_func)
 
 	if (priv->slave_arptype == ARPHRD_INFINIBAND) {
 		new_connection_of_type (priv->toplevel,
+		                        NULL,
 		                        NULL,
 		                        CE_PAGE (self)->client,
 		                        infiniband_connection_new,
@@ -601,6 +600,7 @@ ce_page_bond_class_init (CEPageBondClass *bond_class)
 void
 bond_connection_new (GtkWindow *parent,
                      const char *detail,
+                     gpointer detail_data,
                      NMClient *client,
                      PageNewConnectionResultFunc result_func,
                      gpointer user_data)
