@@ -224,9 +224,7 @@ populate_ui (CEPageEthernet *self)
 
 	/* MTU */
 	mtu_def = ce_get_property_default (NM_SETTING (setting), NM_SETTING_WIRED_MTU);
-	g_signal_connect (priv->mtu, "output",
-	                  G_CALLBACK (ce_spin_output_with_automatic),
-	                  GINT_TO_POINTER (mtu_def));
+	ce_spin_automatic_val (priv->mtu, mtu_def);
 
 	gtk_spin_button_set_value (priv->mtu, (gdouble) nm_setting_wired_get_mtu (setting));
 
@@ -491,6 +489,7 @@ ce_page_ethernet_class_init (CEPageEthernetClass *ethernet_class)
 void
 ethernet_connection_new (GtkWindow *parent,
                          const char *detail,
+                         gpointer detail_data,
                          NMClient *client,
                          PageNewConnectionResultFunc result_func,
                          gpointer user_data)
